![Logo FRT](https://i.imgur.com/qrzMIjp.png)

---

![GitHub top language](https://img.shields.io/github/languages/top/vanBrakel/EmpiricalFinanceToolbox)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/vanBrakel/EmpiricalFinanceToolbox)
![PyPI](https://img.shields.io/pypi/v/apt-py)
![GitHub All Releases](https://img.shields.io/github/downloads/vanBrakel/EmpiricalFinanceToolbox/total)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/vanBrakel/EmpiricalFinanceToolbox)
![GitHub](https://img.shields.io/github/license/vanBrakel/EmpiricalFinanceToolbox)
